==> knative-model-4.7.0-sources.jar: io/fabric8/knative/serving/v1beta1/ConfigurationFluentImpl.java <==
package io.fabric8.knative.serving.v1beta1;

import io.fabric8.knative.serving.v1.ConfigurationStatusBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.knative.serving.v1.ConfigurationStatus;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.knative.serving.v1.ConfigurationSpecFluentImpl;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.knative.serving.v1.ConfigurationSpecBuilder;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.knative.serving.v1.ConfigurationStatusFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.StringBuffer;
import java.lang.Object;
import io.fabric8.knative.serving.v1.ConfigurationSpec;

public class ConfigurationFluentImpl<A extends io.fabric8.knative.serving.v1beta1.ConfigurationFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.knative.serving.v1beta1.ConfigurationFluent<A>{

    private String apiVersion;
    private String kind;
    private ObjectMetaBuilder metadata;
    private ConfigurationSpecBuilder spec;
    private ConfigurationStatusBuilder status;

    public ConfigurationFluentImpl(){
    }
    public ConfigurationFluentImpl(io.fabric8.knative.serving.v1beta1.Configuration instance){
            this.withApiVersion(instance.getApiVersion()); 
            this.withKind(instance.getKind()); 
            this.withMetadata(instance.getMetadata()); 
            this.withSpec(instance.getSpec()); 
            this.withStatus(instance.getStatus()); 
    }

    public String getApiVersion(){
            return this.apiVersion;
    }

    public A withApiVersion(String apiVersion){
            this.apiVersion=apiVersion; return (A) this;
    }

    public Boolean hasApiVersion(){
            return this.apiVersion != null;
    }

    public A withNewApiVersion(String arg1){
            return (A)withApiVersion(new String(arg1));
    }

    public A withNewApiVersion(StringBuilder arg1){
            return (A)withApiVersion(new String(arg1));
    }

    public A withNewApiVersion(StringBuffer arg1){
            return (A)withApiVersion(new String(arg1));
    }

    public String getKind(){
            return this.kind;
    }

    public A withKind(String kind){
            this.kind=kind; return (A) this;
    }

    public Boolean hasKind(){
            return this.kind != null;
    }

    public A withNewKind(String arg1){
            return (A)withKind(new String(arg1));
    }

    public A withNewKind(StringBuilder arg1){
            return (A)withKind(new String(arg1));
    }

    public A withNewKind(StringBuffer arg1){
            return (A)withKind(new String(arg1));
    }

    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public ObjectMeta getMetadata(){
            return this.metadata!=null?this.metadata.build():null;
    }

    public ObjectMeta buildMetadata(){
            return this.metadata!=null?this.metadata.build():null;
    }

    public A withMetadata(ObjectMeta metadata){
            _visitables.get("metadata").remove(this.metadata);
            if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} return (A) this;
    }

    public Boolean hasMetadata(){
            return this.metadata != null;
    }

    public ConfigurationFluent.MetadataNested<A> withNewMetadata(){
            return new MetadataNestedImpl();
    }

    public ConfigurationFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item){
            return new MetadataNestedImpl(item);
    }

    public ConfigurationFluent.MetadataNested<A> editMetadata(){
            return withNewMetadataLike(getMetadata());
    }

    public ConfigurationFluent.MetadataNested<A> editOrNewMetadata(){
            return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
    }

    public ConfigurationFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item){
            return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
    }

    
/**
 * This method has been deprecated, please use method buildSpec instead.
 * @return The buildable object.
 */
@Deprecated public ConfigurationSpec getSpec(){
            return this.spec!=null?this.spec.build():null;
    }

    public ConfigurationSpec buildSpec(){
            return this.spec!=null?this.spec.build():null;
    }

    public A withSpec(ConfigurationSpec spec){
            _visitables.get("spec").remove(this.spec);
            if (spec!=null){ this.spec= new ConfigurationSpecBuilder(spec); _visitables.get("spec").add(this.spec);} return (A) this;
    }

    public Boolean hasSpec(){
            return this.spec != null;
    }

    public ConfigurationFluent.SpecNested<A> withNewSpec(){
            return new SpecNestedImpl();
    }

    public ConfigurationFluent.SpecNested<A> withNewSpecLike(ConfigurationSpec item){
            return new SpecNestedImpl(item);
    }

    public ConfigurationFluent.SpecNested<A> editSpec(){
            return withNewSpecLike(getSpec());
    }

    public ConfigurationFluent.SpecNested<A> editOrNewSpec(){
            return withNewSpecLike(getSpec() != null ? getSpec(): new ConfigurationSpecBuilder().build());
    }

    public ConfigurationFluent.SpecNested<A> editOrNewSpecLike(ConfigurationSpec item){
            return withNewSpecLike(getSpec() != null ? getSpec(): item);
    }

    
/**
 * This method has been deprecated, please use method buildStatus instead.
 * @return The buildable object.
 */
@Deprecated public ConfigurationStatus getStatus(){
            return this.status!=null?this.status.build():null;
    }

    public ConfigurationStatus buildStatus(){
            return this.status!=null?this.status.build():null;
    }

    public A withStatus(ConfigurationStatus status){
            _visitables.get("status").remove(this.status);
            if (status!=null){ this.status= new ConfigurationStatusBuilder(status); _visitables.get("status").add(this.status);} return (A) this;
    }

    public Boolean hasStatus(){
            return this.status != null;
    }

    public ConfigurationFluent.StatusNested<A> withNewStatus(){
            return new StatusNestedImpl();
    }

    public ConfigurationFluent.StatusNested<A> withNewStatusLike(ConfigurationStatus item){
            return new StatusNestedImpl(item);
    }

    public ConfigurationFluent.StatusNested<A> editStatus(){
            return withNewStatusLike(getStatus());
    }

    public ConfigurationFluent.StatusNested<A> editOrNewStatus(){
            return withNewStatusLike(getStatus() != null ? getStatus(): new ConfigurationStatusBuilder().build());
    }

    public ConfigurationFluent.StatusNested<A> editOrNewStatusLike(ConfigurationStatus item){
            return withNewStatusLike(getStatus() != null ? getStatus(): item);
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            ConfigurationFluentImpl that = (ConfigurationFluentImpl) o;
            if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
            if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
            if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
            if (spec != null ? !spec.equals(that.spec) :that.spec != null) return false;
            if (status != null ? !status.equals(that.status) :that.status != null) return false;
            return true;
    }


    public class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<ConfigurationFluent.MetadataNested<N>> implements ConfigurationFluent.MetadataNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{

            private final ObjectMetaBuilder builder;
    
            MetadataNestedImpl(ObjectMeta item){
                    this.builder = new ObjectMetaBuilder(this, item);
            }
            MetadataNestedImpl(){
                    this.builder = new ObjectMetaBuilder(this);
            }
    
    public N and(){
            return (N) ConfigurationFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata(){
            return and();
    }

}
    public class SpecNestedImpl<N> extends ConfigurationSpecFluentImpl<ConfigurationFluent.SpecNested<N>> implements ConfigurationFluent.SpecNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{

            private final ConfigurationSpecBuilder builder;
    
            SpecNestedImpl(ConfigurationSpec item){
                    this.builder = new ConfigurationSpecBuilder(this, item);
            }
            SpecNestedImpl(){
                    this.builder = new ConfigurationSpecBuilder(this);
            }
    
    public N and(){
            return (N) ConfigurationFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec(){
            return and();
    }

}
    public class StatusNestedImpl<N> extends ConfigurationStatusFluentImpl<ConfigurationFluent.StatusNested<N>> implements ConfigurationFluent.StatusNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{

            private final ConfigurationStatusBuilder builder;
    
            StatusNestedImpl(ConfigurationStatus item){
                    this.builder = new ConfigurationStatusBuilder(this, item);
            }
            StatusNestedImpl(){
                    this.builder = new ConfigurationStatusBuilder(this);
            }
    
    public N and(){
            return (N) ConfigurationFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus(){
            return and();
    }

}


}

==> knative-model-4.11.2-sources.jar: io/fabric8/knative/serving/v1beta1/ConfigurationFluentImpl.java <==
package io.fabric8.knative.serving.v1beta1;

import io.fabric8.knative.internal.serving.pkg.apis.serving.v1.ConfigurationStatusBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.knative.internal.serving.pkg.apis.serving.v1.ConfigurationStatus;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.knative.internal.serving.pkg.apis.serving.v1.ConfigurationSpecFluentImpl;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.knative.internal.serving.pkg.apis.serving.v1.ConfigurationSpecBuilder;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.knative.internal.serving.pkg.apis.serving.v1.ConfigurationStatusFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.StringBuffer;
import java.lang.Object;
import io.fabric8.knative.internal.serving.pkg.apis.serving.v1.ConfigurationSpec;

public class ConfigurationFluentImpl<A extends io.fabric8.knative.serving.v1beta1.ConfigurationFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.knative.serving.v1beta1.ConfigurationFluent<A>{

    private String apiVersion;
    private String kind;
    private ObjectMetaBuilder metadata;
    private ConfigurationSpecBuilder spec;
    private ConfigurationStatusBuilder status;

    public ConfigurationFluentImpl(){
    }
    public ConfigurationFluentImpl(io.fabric8.knative.serving.v1beta1.Configuration instance){
            this.withApiVersion(instance.getApiVersion()); 
            this.withKind(instance.getKind()); 
            this.withMetadata(instance.getMetadata()); 
            this.withSpec(instance.getSpec()); 
            this.withStatus(instance.getStatus()); 
    }

    public String getApiVersion(){
            return this.apiVersion;
    }

    public A withApiVersion(String apiVersion){
            this.apiVersion=apiVersion; return (A) this;
    }

    public Boolean hasApiVersion(){
            return this.apiVersion != null;
    }

    public A withNewApiVersion(String arg1){
            return (A)withApiVersion(new String(arg1));
    }

    public A withNewApiVersion(StringBuilder arg1){
            return (A)withApiVersion(new String(arg1));
    }

    public A withNewApiVersion(StringBuffer arg1){
            return (A)withApiVersion(new String(arg1));
    }

    public String getKind(){
            return this.kind;
    }

    public A withKind(String kind){
            this.kind=kind; return (A) this;
    }

    public Boolean hasKind(){
            return this.kind != null;
    }

    public A withNewKind(String arg1){
            return (A)withKind(new String(arg1));
    }

    public A withNewKind(StringBuilder arg1){
            return (A)withKind(new String(arg1));
    }

    public A withNewKind(StringBuffer arg1){
            return (A)withKind(new String(arg1));
    }

    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public ObjectMeta getMetadata(){
            return this.metadata!=null?this.metadata.build():null;
    }

    public ObjectMeta buildMetadata(){
            return this.metadata!=null?this.metadata.build():null;
    }

    public A withMetadata(ObjectMeta metadata){
            _visitables.get("metadata").remove(this.metadata);
            if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} return (A) this;
    }

    public Boolean hasMetadata(){
            return this.metadata != null;
    }

    public ConfigurationFluent.MetadataNested<A> withNewMetadata(){
            return new MetadataNestedImpl();
    }

    public ConfigurationFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item){
            return new MetadataNestedImpl(item);
    }

    public ConfigurationFluent.MetadataNested<A> editMetadata(){
            return withNewMetadataLike(getMetadata());
    }

    public ConfigurationFluent.MetadataNested<A> editOrNewMetadata(){
            return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
    }

    public ConfigurationFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item){
            return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
    }

    
/**
 * This method has been deprecated, please use method buildSpec instead.
 * @return The buildable object.
 */
@Deprecated public ConfigurationSpec getSpec(){
            return this.spec!=null?this.spec.build():null;
    }

    public ConfigurationSpec buildSpec(){
            return this.spec!=null?this.spec.build():null;
    }

    public A withSpec(ConfigurationSpec spec){
            _visitables.get("spec").remove(this.spec);
            if (spec!=null){ this.spec= new ConfigurationSpecBuilder(spec); _visitables.get("spec").add(this.spec);} return (A) this;
    }

    public Boolean hasSpec(){
            return this.spec != null;
    }

    public ConfigurationFluent.SpecNested<A> withNewSpec(){
            return new SpecNestedImpl();
    }

    public ConfigurationFluent.SpecNested<A> withNewSpecLike(ConfigurationSpec item){
            return new SpecNestedImpl(item);
    }

    public ConfigurationFluent.SpecNested<A> editSpec(){
            return withNewSpecLike(getSpec());
    }

    public ConfigurationFluent.SpecNested<A> editOrNewSpec(){
            return withNewSpecLike(getSpec() != null ? getSpec(): new ConfigurationSpecBuilder().build());
    }

    public ConfigurationFluent.SpecNested<A> editOrNewSpecLike(ConfigurationSpec item){
            return withNewSpecLike(getSpec() != null ? getSpec(): item);
    }

    
/**
 * This method has been deprecated, please use method buildStatus instead.
 * @return The buildable object.
 */
@Deprecated public ConfigurationStatus getStatus(){
            return this.status!=null?this.status.build():null;
    }

    public ConfigurationStatus buildStatus(){
            return this.status!=null?this.status.build():null;
    }

    public A withStatus(ConfigurationStatus status){
            _visitables.get("status").remove(this.status);
            if (status!=null){ this.status= new ConfigurationStatusBuilder(status); _visitables.get("status").add(this.status);} return (A) this;
    }

    public Boolean hasStatus(){
            return this.status != null;
    }

    public ConfigurationFluent.StatusNested<A> withNewStatus(){
            return new StatusNestedImpl();
    }

    public ConfigurationFluent.StatusNested<A> withNewStatusLike(ConfigurationStatus item){
            return new StatusNestedImpl(item);
    }

    public ConfigurationFluent.StatusNested<A> editStatus(){
            return withNewStatusLike(getStatus());
    }

    public ConfigurationFluent.StatusNested<A> editOrNewStatus(){
            return withNewStatusLike(getStatus() != null ? getStatus(): new ConfigurationStatusBuilder().build());
    }

    public ConfigurationFluent.StatusNested<A> editOrNewStatusLike(ConfigurationStatus item){
            return withNewStatusLike(getStatus() != null ? getStatus(): item);
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            ConfigurationFluentImpl that = (ConfigurationFluentImpl) o;
            if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
            if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
            if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
            if (spec != null ? !spec.equals(that.spec) :that.spec != null) return false;
            if (status != null ? !status.equals(that.status) :that.status != null) return false;
            return true;
    }


    public class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<ConfigurationFluent.MetadataNested<N>> implements ConfigurationFluent.MetadataNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{

            private final ObjectMetaBuilder builder;
    
            MetadataNestedImpl(ObjectMeta item){
                    this.builder = new ObjectMetaBuilder(this, item);
            }
            MetadataNestedImpl(){
                    this.builder = new ObjectMetaBuilder(this);
            }
    
    public N and(){
            return (N) ConfigurationFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata(){
            return and();
    }

}
    public class SpecNestedImpl<N> extends ConfigurationSpecFluentImpl<ConfigurationFluent.SpecNested<N>> implements ConfigurationFluent.SpecNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{

            private final ConfigurationSpecBuilder builder;
    
            SpecNestedImpl(ConfigurationSpec item){
                    this.builder = new ConfigurationSpecBuilder(this, item);
            }
            SpecNestedImpl(){
                    this.builder = new ConfigurationSpecBuilder(this);
            }
    
    public N and(){
            return (N) ConfigurationFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec(){
            return and();
    }

}
    public class StatusNestedImpl<N> extends ConfigurationStatusFluentImpl<ConfigurationFluent.StatusNested<N>> implements ConfigurationFluent.StatusNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{

            private final ConfigurationStatusBuilder builder;
    
            StatusNestedImpl(ConfigurationStatus item){
                    this.builder = new ConfigurationStatusBuilder(this, item);
            }
            StatusNestedImpl(){
                    this.builder = new ConfigurationStatusBuilder(this);
            }
    
    public N and(){
            return (N) ConfigurationFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus(){
            return and();
    }

}


}
